==> odoo_addon_delivery_carrier_manual_weight-17.0.1.0.0.4-py3-none-any.whl: odoo/addons/delivery_carrier_manual_weight/tests/test_delivery_carrier_manual_weight.py <==
# Copyright 2024 ForgeFlow S.L. (https://www.forgeflow.com)
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl)
from odoo.tests import Form
from odoo.tests.common import TransactionCase


class TestDeliveryCarrierManualWeight(TransactionCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        product_shipping_cost = cls.env["product.product"].create(
            {
                "type": "service",
                "name": "Shipping costs",
                "standard_price": 10,
                "list_price": 100,
            }
        )
        cls.carrier = cls.env["delivery.carrier"].create(
            {
                "name": "Test carrier",
                "delivery_type": "fixed",
                "product_id": product_shipping_cost.id,
                "fixed_price": 50,
                "is_manual_weight": True,
            }
        )
        cls.product = cls.env["product.product"].create(
            {"name": "Test product", "type": "product"}
        )
        cls.partner = cls.env["res.partner"].create({"name": "Test Partner"})
        cls.sale = cls.env["sale.order"].create(
            {
                "partner_id": cls.partner.id,
                "order_line": [
                    (
                        0,
                        0,
                        {
                            "product_id": cls.product.id,
                            "product_uom_qty": 1,
                        },
                    )
                ],
            }
        )

    def test_delivery_carrier_manual_weight(self):
        delivery_wizard = Form(
            self.env["choose.delivery.carrier"].with_context(
                **{"default_order_id": self.sale.id, "default_carrier_id": self.carrier}
            )
        )
        choose_delivery_carrier = delivery_wizard.save()
        choose_delivery_carrier.button_confirm()
        self.sale.action_confirm()
        picking = self.sale.picking_ids[0]
        with Form(picking) as form:
            form.weight_manual = 89
            form.shipping_weight_manual = 99
        picking._cal_weight()
        picking._compute_shipping_weight()
        self.assertEqual(picking.weight, 89)
        self.assertEqual(picking.shipping_weight, 99)

==> odoo_addon_delivery_carrier_manual_weight-18.0.1.0.0.2-py3-none-any.whl: odoo/addons/delivery_carrier_manual_weight/tests/test_delivery_carrier_manual_weight.py <==
# Copyright 2024 ForgeFlow S.L. (https://www.forgeflow.com)
# License AGPL-3.0 or later (https://www.gnu.org/licenses/agpl)
from odoo import Command
from odoo.tests import Form

from odoo.addons.base.tests.common import BaseCommon


class TestDeliveryCarrierManualWeight(BaseCommon):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()
        product_shipping_cost = cls.env["product.product"].create(
            {
                "type": "service",
                "name": "Shipping costs",
                "standard_price": 10,
                "list_price": 100,
            }
        )
        cls.carrier = cls.env["delivery.carrier"].create(
            {
                "name": "Test carrier",
                "delivery_type": "fixed",
                "product_id": product_shipping_cost.id,
                "fixed_price": 50,
                "is_manual_weight": True,
            }
        )
        cls.product = cls.env["product.product"].create(
            {"name": "Test product", "type": "consu"}
        )
        cls.partner = cls.env["res.partner"].create({"name": "Test Partner"})
        cls.sale = cls.env["sale.order"].create(
            {
                "partner_id": cls.partner.id,
                "order_line": [
                    Command.create(
                        {
                            "product_id": cls.product.id,
                            "product_uom_qty": 1,
                        },
                    )
                ],
            }
        )

    def test_delivery_carrier_manual_weight(self):
        delivery_wizard = Form(
            self.env["choose.delivery.carrier"].with_context(
                **{"default_order_id": self.sale.id, "default_carrier_id": self.carrier}
            )
        )
        choose_delivery_carrier = delivery_wizard.save()
        choose_delivery_carrier.button_confirm()
        self.sale.action_confirm()
        picking = self.sale.picking_ids[0]
        with Form(picking) as form:
            form.weight_manual = 89
            form.shipping_weight_manual = 99
        picking._cal_weight()
        picking._compute_shipping_weight()
        self.assertEqual(picking.weight, 89)
        self.assertEqual(picking.shipping_weight, 99)
